@@ -1,5 +1,5 @@
 import {Component, OnInit} from "@angular/core";
-import {TitleService} from "@synerty/peek-util";
+import { TitleService } from "@synerty/peek-plugin-base-js"
 
 import {ComponentLifecycleEventEmitter} from "@synerty/vortexjs";
 
@@ -47,4 +47,4 @@ export class ConnectingComponent extends ComponentLifecycleEventEmitter  impleme
     }
 
 
-}
\ No newline at end of file
+}
