@@ -1,5 +1,5 @@
 import {Component, OnInit} from "@angular/core";
-import {TitleService} from "@synerty/peek-util";
+import { TitleService } from "@synerty/peek-plugin-base-js"
 import {Observable} from "rxjs/Observable";
 
 import {ComponentLifecycleEventEmitter} from "@synerty/vortexjs";
@@ -25,4 +25,4 @@ export class LoadingComponent extends ComponentLifecycleEventEmitter implements
         this.titleService.setTitle('');
     }
 
-}
\ No newline at end of file
+}
