@@ -1,6 +1,6 @@
 import {Component, OnInit} from "@angular/core";
-import {TitleService} from "@synerty/peek-util";
-import {Ng2BalloonMsgService} from "@synerty/ng2-balloon-msg";
+import { TitleService } from "@synerty/peek-plugin-base-js"
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
 
 import {
     DeviceNavService,
@@ -31,7 +31,7 @@ export class ConnectComponent extends ComponentLifecycleEventEmitter implements
     deviceType: DeviceTypeEnum;
     isWeb: boolean;
 
-    constructor(private balloonMsg: Ng2BalloonMsgService,
+    constructor(private balloonMsg: BalloonMsgService,
                 private titleService: TitleService,
                 private tupleService: DeviceTupleService,
                 private deviceServerService: DeviceServerService) {
@@ -93,4 +93,4 @@ export class ConnectComponent extends ComponentLifecycleEventEmitter implements
     }
 
 
-}
\ No newline at end of file
+}
